ioctl_ptr

Function ioctl_ptr 

pub unsafe fn ioctl_ptr(
    fd: i32,
    request: c_ulong,
    arg: *mut c_void,
) -> Result<i32>
Safety

arg must be a valid pointer for the request passed to ioctl and must satisfy the platform ABI requirements for that request.