write_stderr_raw

Function write_stderr_raw 

pub fn write_stderr_raw(buf: &[u8])
Async-signal-safe raw write to the platform stderr file descriptor. Avoids std::io::stderr() locking so it is safe to call from fork children and signal handlers.