remove_var

Function remove_var 

pub unsafe fn remove_var(key: impl AsRef<OsStr>)
Safety

The caller must ensure no other threads can concurrently read or write the process environment while this mutation is performed.