pub struct EventFlags(/* private fields */);Expand description
EPOLL* for use with epoll::add.
Implementations
Sourceimpl EventFlags
impl EventFlags
Sourcepub const IN: EventFlags
pub const IN: EventFlags
EPOLLIN
Sourcepub const OUT: EventFlags
pub const OUT: EventFlags
EPOLLOUT
Sourcepub const PRI: EventFlags
pub const PRI: EventFlags
EPOLLPRI
Sourcepub const ERR: EventFlags
pub const ERR: EventFlags
EPOLLERR
Sourcepub const HUP: EventFlags
pub const HUP: EventFlags
EPOLLHUP
Sourcepub const RDNORM: EventFlags
pub const RDNORM: EventFlags
EPOLLRDNORM
Sourcepub const RDBAND: EventFlags
pub const RDBAND: EventFlags
EPOLLRDBAND
Sourcepub const WRNORM: EventFlags
pub const WRNORM: EventFlags
EPOLLWRNORM
Sourcepub const WRBAND: EventFlags
pub const WRBAND: EventFlags
EPOLLWRBAND
Sourcepub const MSG: EventFlags
pub const MSG: EventFlags
EPOLLMSG
Sourcepub const RDHUP: EventFlags
pub const RDHUP: EventFlags
EPOLLRDHUP
Sourcepub const ET: EventFlags
pub const ET: EventFlags
EPOLLET
Sourcepub const ONESHOT: EventFlags
pub const ONESHOT: EventFlags
EPOLLONESHOT
Sourcepub const WAKEUP: EventFlags
pub const WAKEUP: EventFlags
EPOLLWAKEUP
Sourcepub const EXCLUSIVE: EventFlags
pub const EXCLUSIVE: EventFlags
EPOLLEXCLUSIVE
Sourceimpl EventFlags
impl EventFlags
Sourcepub const fn empty() -> EventFlags
pub const fn empty() -> EventFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> EventFlags
pub const fn all() -> EventFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<EventFlags>
pub const fn from_bits(bits: u32) -> Option<EventFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> EventFlags
pub const fn from_bits_truncate(bits: u32) -> EventFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> EventFlags
pub const fn from_bits_retain(bits: u32) -> EventFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<EventFlags>
pub fn from_name(name: &str) -> Option<EventFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: EventFlags) -> bool
pub const fn intersects(&self, other: EventFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: EventFlags) -> bool
pub const fn contains(&self, other: EventFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: EventFlags)
pub fn insert(&mut self, other: EventFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: EventFlags)
pub fn remove(&mut self, other: EventFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: EventFlags)
pub fn toggle(&mut self, other: EventFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: EventFlags, value: bool)
pub fn set(&mut self, other: EventFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: EventFlags) -> EventFlags
pub const fn intersection(self, other: EventFlags) -> EventFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: EventFlags) -> EventFlags
pub const fn union(self, other: EventFlags) -> EventFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: EventFlags) -> EventFlags
pub const fn difference(self, other: EventFlags) -> EventFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: EventFlags) -> EventFlags
pub const fn symmetric_difference(self, other: EventFlags) -> EventFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> EventFlags
pub const fn complement(self) -> EventFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl EventFlags
impl EventFlags
Sourcepub const fn iter(&self) -> Iter<EventFlags> ⓘ
pub const fn iter(&self) -> Iter<EventFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<EventFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<EventFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.