install_handler

Function install_handler 

pub unsafe fn install_handler(
    signalnum: i32,
    handler: sighandler_t,
) -> Result<sighandler_t>
Safety

The caller must ensure signalnum is a valid platform signal number and handler is accepted by the platform signal ABI.