Modules
- crt_fd
- A module implementing an io type backed by the C runtime’s file descriptors, i.e. what’s returned from libc::open, even on windows.
- errno
- faulthandler
- fcntl
- fileutils
- fs
- grp
- io
- locale
- mmap
- multiprocessing
- os
- posix
- posix_
unix_ like - Common POSIX implementations across Unix-likes.
- pwd
- readline
- Readline interface for REPLs
- resource
- select
- shm
- signal
- socket
- syslog
- termios
- thread
- time
Macros
- suppress_
iph - Suppress the MSVC invalid parameter handler, which by default crashes the process. Does nothing on non-MSVC targets.