Structs
Enums
Functions
- close_
owned_ fd - inspect_
file_ target - is_
interrupted_ errno - is_
interrupted_ error - is_
seekable - is_
would_ block_ error - isatty
- open_
path - parse_
fileio_ mode - read_
all - read_
once - reads_
without_ waiting - Whether a read from
fdanswers from data the file already holds, rather than waiting for whoever writes the other end. - seek
- seek_
to_ end - should_
forget_ fd_ after_ inspect_ error - tell
- validate_
whence - write_
once - write_
stderr_ raw - Async-signal-safe raw write to the platform stderr file descriptor.
Avoids
std::io::stderr()locking so it is safe to call from fork children and signal handlers.