pub unsafe fn set_var(key: impl AsRef<OsStr>, value: impl AsRef<OsStr>)
The caller must ensure no other threads can concurrently read or write the process environment while this mutation is performed.